# Base Docker images

This images include [Resolwe Runtime Utilities](
http://resolwe-runtime-utils.readthedocs.io).

The `fedora-26` image is based on [`docker.io/fedora:26`](
https://hub.docker.com/_/fedora/).
The `ubuntu-17.10` and `ubuntu-18.04` images are based on
[`docker.io/ubuntu:17.10`](https://hub.docker.com/_/ubuntu/), and
[`docker.io/ubuntu:18.04`](https://hub.docker.com/_/ubuntu/)
respectively.

The base images are used as bases for all the other
Resolwe toolkit Docker images.
